@@ -7,6 +7,7 @@ import six
 import xmltodict
 
 
+requests.packages.urllib3.disable_warnings()
 log = logging.getLogger(__name__)
 
 
@@ -185,6 +186,13 @@ class LoadMaster(HttpClient):
                           url)
             raise KempTechApiError(response.text)
 
+    def stats(self):
+        response = self._get('stats')
+        if ApiXmlHelper.is_successful(response):
+            return ApiXmlHelper.parse_to_dict(response)
+        else:
+            raise KempTechApiError(ApiXmlHelper.get_error_msg(response))
+
     def update_firmware(self, file):
         response = self._post('installpatch', file)
         return ApiXmlHelper.is_successful(response)
@@ -219,7 +227,7 @@ class KempTechApiError(Exception):
             elif code == 403:
                 message = "403 Incorrect permissions."
             elif code == 404:
-                message = ("404 Not found."
+                message = ("404 Not found. "
                            "Ensure the API is enabled on the LoadMaster.")
             elif code == 405:
                 message = "405 Unknown command."
